/*
 * Copyright (C) 2006, 2007 OpenedHand Ltd.
 *
 * Author: Jorn Baayen <jorn@openedhand.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GUPNP_DEVICE_PROXY_PRIVATE_H__
#define __GUPNP_DEVICE_PROXY_PRIVATE_H__

#include <libxml/tree.h>

#include "gupnp-context.h"
#include "gupnp-device-proxy.h"
#include "xml-util.h"

GUPnPDeviceProxy *
_gupnp_device_proxy_new (GUPnPContext  *context,
                         XmlDocWrapper *doc,
                         xmlNode       *element,
                         const char    *udn,
                         const char    *location,
                         const SoupUri *url_base);

#endif /* __GUPNP_DEVICE_PROXY_PRIVATE_H__ */
